@@ -12,8 +12,8 @@
 
 #include "config.h"
 
-Lum::AppInfo info;
-GUI*         GUI::instance=NULL;
+static Lum::Def::AppInfo info;
+GUI*                     GUI::instance=NULL;
 
 GUI::GUI()
 : defaultView(NULL)
